summaryrefslogtreecommitdiff
path: root/nuttx/configs/shenzhou/nsh
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-09-09 15:43:18 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-09-09 15:43:18 +0000
commit78c6aa16fdd3926e15fa16ebab33ea416031ac11 (patch)
tree9c993b977665a0c00e06690f81a26a760d61831a /nuttx/configs/shenzhou/nsh
parent7d909957bf5f3b984d2be3779b02b55d7f42e4bb (diff)
downloadpx4-nuttx-78c6aa16fdd3926e15fa16ebab33ea416031ac11.tar.gz
px4-nuttx-78c6aa16fdd3926e15fa16ebab33ea416031ac11.tar.bz2
px4-nuttx-78c6aa16fdd3926e15fa16ebab33ea416031ac11.zip
Reconfigured Shenzhou to use JTAG. Misc Kconfig changes
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@5118 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/configs/shenzhou/nsh')
-rw-r--r--nuttx/configs/shenzhou/nsh/defconfig13
-rwxr-xr-xnuttx/configs/shenzhou/nsh/setenv.sh7
2 files changed, 16 insertions, 4 deletions
diff --git a/nuttx/configs/shenzhou/nsh/defconfig b/nuttx/configs/shenzhou/nsh/defconfig
index 907871104..2030b232b 100644
--- a/nuttx/configs/shenzhou/nsh/defconfig
+++ b/nuttx/configs/shenzhou/nsh/defconfig
@@ -70,12 +70,15 @@ CONFIG_ARCH_FAMILY="armv7-m"
CONFIG_ARCH_CHIP="stm32"
CONFIG_ARCH_HAVE_MPU=y
# CONFIG_ARMV7M_MPU is not set
-# CONFIG_ARCH_INTERRUPTSTACK is not set
CONFIG_ARCH_IRQPRIO=y
CONFIG_BOARD_LOOPSPERMSEC=5483
# CONFIG_ARCH_CALIBRATION is not set
# CONFIG_SERIAL_TERMIOS is not set
# CONFIG_NET_MULTICAST is not set
+
+#
+# STM32 Configuration Options
+#
# CONFIG_ARCH_CHIP_STM32F103ZET6 is not set
# CONFIG_ARCH_CHIP_STM32F103RET6 is not set
# CONFIG_ARCH_CHIP_STM32F103VCT6 is not set
@@ -100,7 +103,7 @@ CONFIG_STM32_CODESOURCERYW=y
# CONFIG_STM32_DEVKITARM is not set
# CONFIG_STM32_RAISONANCE is not set
# CONFIG_STM32_BUILDROOT is not set
-CONFIG_STM32_DFU=y
+# CONFIG_STM32_DFU is not set
#
# STM32 Peripheral Support
@@ -139,6 +142,10 @@ CONFIG_STM32_USART2=y
# CONFIG_STM32_USB is not set
# CONFIG_STM32_WWDG is not set
CONFIG_STM32_SPI=y
+
+#
+# Alternate Pin Mapping
+#
CONFIG_STM32_USART2_REMAP=y
# CONFIG_STM32_SPI1_REMAP is not set
CONFIG_STM32_ETH_REMAP=y
@@ -184,6 +191,8 @@ CONFIG_ARCH_STACKDUMP=y
#
CONFIG_DRAM_START=0x20000000
CONFIG_DRAM_SIZE=65536
+CONFIG_ARCH_HAVE_INTERRUPTSTACK=y
+# CONFIG_ARCH_INTERRUPTSTACK is not set
#
# Boot options
diff --git a/nuttx/configs/shenzhou/nsh/setenv.sh b/nuttx/configs/shenzhou/nsh/setenv.sh
index 1ba336393..d57d6f003 100755
--- a/nuttx/configs/shenzhou/nsh/setenv.sh
+++ b/nuttx/configs/shenzhou/nsh/setenv.sh
@@ -69,7 +69,10 @@ export TOOLCHAIN_BIN="/cygdrive/c/Program Files (x86)/CodeSourcery/Sourcery G++
# toolchain.
#export TOOLCHAIN_BIN="${WD}/../misc/buildroot/build_arm_nofpu/staging_dir/bin"
-# Add the path to the toolchain to the PATH varialble
-export PATH="${TOOLCHAIN_BIN}:/sbin:/usr/sbin:${PATH_ORIG}"
+# This is the path to the tools/ subdirectory
+export TOOLS_DIR="${WD}/configs/shenzhou/tools"
+
+# Add the path to the toolchain to the PATH variable
+export PATH="${TOOLCHAIN_BIN}:${TOOLS_DIR}:/sbin:/usr/sbin:${PATH_ORIG}"
echo "PATH : ${PATH}"